@@ -141,8 +141,8 @@ pub fn split_series(s: &Series, n: usize) -> PolarsResult<Vec<Series>> {
 }
 
 fn flatten_df(df: &DataFrame) -> impl Iterator<Item = DataFrame> + '_ {
-    df.iter_chunks().map(|chunk| {
-        DataFrame::new_no_checks(
+    df.iter_chunks().flat_map(|chunk| {
+        let df = DataFrame::new_no_checks(
             df.iter()
                 .zip(chunk.into_arrays())
                 .map(|(s, arr)| {
@@ -153,19 +153,15 @@ fn flatten_df(df: &DataFrame) -> impl Iterator<Item = DataFrame> + '_ {
                     }
                 })
                 .collect(),
-        )
+        );
+        if df.height() == 0 {
+            None
+        } else {
+            Some(df)
+        }
     })
 }
-
-#[cfg(feature = "private")]
-#[doc(hidden)]
-/// Split a [`DataFrame`] into `n` parts. We take a `&mut` to be able to repartition/align chunks.
-pub fn split_df(df: &mut DataFrame, n: usize) -> PolarsResult<Vec<DataFrame>> {
-    if n == 0 {
-        return Ok(vec![df.clone()]);
-    }
-    // make sure that chunks are aligned.
-    df.rechunk();
+pub fn split_df_as_ref(df: &DataFrame, n: usize) -> PolarsResult<Vec<DataFrame>> {
     let total_len = df.height();
     let chunk_size = total_len / n;
 
@@ -199,6 +195,18 @@ pub fn split_df(df: &mut DataFrame, n: usize) -> PolarsResult<Vec<DataFrame>> {
     Ok(out)
 }
 
+#[cfg(feature = "private")]
+#[doc(hidden)]
+/// Split a [`DataFrame`] into `n` parts. We take a `&mut` to be able to repartition/align chunks.
+pub fn split_df(df: &mut DataFrame, n: usize) -> PolarsResult<Vec<DataFrame>> {
+    if n == 0 {
+        return Ok(vec![df.clone()]);
+    }
+    // make sure that chunks are aligned.
+    df.rechunk();
+    split_df_as_ref(df, n)
+}
+
 pub fn slice_slice<T>(vals: &[T], offset: i64, len: usize) -> &[T] {
     let (raw_offset, slice_len) = slice_offsets(offset, len, vals.len());
     &vals[raw_offset..raw_offset + slice_len]
