@@ -5,6 +5,7 @@ use polars_io::csv::utils::{get_reader_bytes, infer_file_schema};
 use polars_io::csv::{CsvEncoding, NullValues};
 use polars_io::RowCount;
 
+use crate::dsl::functions::concat;
 use crate::prelude::*;
 
 #[derive(Clone)]
@@ -207,7 +208,7 @@ impl<'a> LazyCsvReader<'a> {
         let reader_bytes = get_reader_bytes(&mut file).expect("could not mmap file");
         let mut skip_rows = self.skip_rows;
 
-        let (schema, _) = infer_file_schema(
+        let (schema, _, _) = infer_file_schema(
             &reader_bytes,
             self.delimiter,
             self.infer_schema_length,
