@@ -1,10 +1,4 @@
-use polars_core::prelude::*;
-use polars_core::POOL;
-use rayon::prelude::*;
-
-use crate::physical_plan::executors::execute_projection_cached_window_fns;
-use crate::physical_plan::state::ExecutionState;
-use crate::prelude::*;
+use super::*;
 
 pub struct StackExec {
     pub(crate) input: Box<dyn Executor>,
@@ -13,16 +7,12 @@ pub struct StackExec {
     pub(crate) input_schema: SchemaRef,
 }
 
-impl Executor for StackExec {
-    fn execute(&mut self, state: &mut ExecutionState) -> Result<DataFrame> {
-        #[cfg(debug_assertions)]
-        {
-            if state.verbose() {
-                println!("run StackExec")
-            }
-        }
-        let mut df = self.input.execute(state)?;
-
+impl StackExec {
+    fn execute_impl(
+        &mut self,
+        state: &mut ExecutionState,
+        mut df: DataFrame,
+    ) -> PolarsResult<DataFrame> {
         state.set_schema(self.input_schema.clone());
         let res = if self.has_windows {
             // we have a different run here
@@ -33,7 +23,7 @@ impl Executor for StackExec {
                 self.expr
                     .par_iter()
                     .map(|expr| expr.evaluate(&df, state))
-                    .collect::<Result<Vec<_>>>()
+                    .collect::<PolarsResult<Vec<_>>>()
             })?
         };
         state.clear_schema_cache();
@@ -53,3 +43,34 @@ impl Executor for StackExec {
         Ok(df)
     }
 }
+
+impl Executor for StackExec {
+    fn execute(&mut self, state: &mut ExecutionState) -> PolarsResult<DataFrame> {
+        #[cfg(debug_assertions)]
+        {
+            if state.verbose() {
+                println!("run StackExec")
+            }
+        }
+        let df = self.input.execute(state)?;
+
+        let profile_name = if state.has_node_timer() {
+            let by = self
+                .expr
+                .iter()
+                .map(|s| Ok(s.to_field(&self.input_schema)?.name))
+                .collect::<PolarsResult<Vec<_>>>()?;
+            let name = column_delimited("with_column".to_string(), &by);
+            Cow::Owned(name)
+        } else {
+            Cow::Borrowed("")
+        };
+
+        if state.has_node_timer() {
+            let new_state = state.clone();
+            new_state.record(|| self.execute_impl(state, df), profile_name)
+        } else {
+            self.execute_impl(state, df)
+        }
+    }
+}
