@@ -1,4 +1,5 @@
 use std::io::{Read, Seek, SeekFrom};
+use std::ops::Deref;
 use std::path::PathBuf;
 use std::sync::Mutex;
 
@@ -21,7 +22,7 @@ use polars_io::{
 
 use crate::logical_plan::functions::FunctionNode;
 use crate::logical_plan::projection::rewrite_projections;
-use crate::logical_plan::schema::det_join_schema;
+use crate::logical_plan::schema::{det_join_schema, FileInfo};
 use crate::prelude::*;
 use crate::utils;
 use crate::utils::{combine_predicates_expr, has_expr};
@@ -72,9 +73,13 @@ impl LogicalPlanBuilder {
             None => function.schema(infer_schema_length)?,
         });
 
+        let file_info = FileInfo {
+            schema: schema.clone(),
+            row_estimation: (n_rows, n_rows.unwrap_or(usize::MAX)),
+        };
         Ok(LogicalPlan::AnonymousScan {
             function,
-            schema: schema.clone(),
+            file_info,
             predicate: None,
             options: AnonymousScanOptions {
                 fmt_str: name,
@@ -83,6 +88,7 @@ impl LogicalPlanBuilder {
                 n_rows,
                 output_schema: None,
                 with_columns: None,
+                predicate: None,
             },
         }
         .into())
@@ -103,11 +109,17 @@ impl LogicalPlanBuilder {
 
         let path = path.into();
         let file = std::fs::File::open(&path)?;
-        let schema = Arc::new(ParquetReader::new(file).schema()?);
+        let mut reader = ParquetReader::new(file);
+        let schema = Arc::new(reader.schema()?);
+        let num_rows = reader.num_rows()?;
+        let file_info = FileInfo {
+            schema,
+            row_estimation: (Some(num_rows), num_rows),
+        };
 
         Ok(LogicalPlan::ParquetScan {
             path,
-            schema,
+            file_info,
             predicate: None,
             options: ParquetOptions {
                 n_rows,
@@ -130,11 +142,17 @@ impl LogicalPlanBuilder {
 
         let path = path.into();
         let file = std::fs::File::open(&path)?;
-        let schema = Arc::new(IpcReader::new(file).schema()?);
+        let mut reader = IpcReader::new(file);
+        let schema = Arc::new(reader.schema()?);
 
+        let num_rows = reader._num_rows()?;
+        let file_info = FileInfo {
+            schema,
+            row_estimation: (None, num_rows),
+        };
         Ok(LogicalPlan::IpcScan {
             path,
-            schema,
+            file_info,
             predicate: None,
             options: options.into(),
         }
@@ -179,28 +197,35 @@ impl LogicalPlanBuilder {
         file.seek(SeekFrom::Start(0))?;
         let reader_bytes = get_reader_bytes(&mut file).expect("could not mmap file");
 
-        let schema = schema.unwrap_or_else(|| {
-            let (schema, _) = infer_file_schema(
-                &reader_bytes,
-                delimiter,
-                infer_schema_length,
-                has_header,
-                schema_overwrite,
-                &mut skip_rows,
-                skip_rows_after_header,
-                comment_char,
-                quote_char,
-                eol_char,
-                null_values.as_ref(),
-                parse_dates,
-            )
-            .expect("could not read schema");
-            Arc::new(schema)
-        });
+        // TODO! delay inferring schema until absolutely necessary
+        // this needs a way to estimated bytes/rows.
+        let (inferred_schema, rows_read, bytes_read) = infer_file_schema(
+            &reader_bytes,
+            delimiter,
+            infer_schema_length,
+            has_header,
+            schema_overwrite,
+            &mut skip_rows,
+            skip_rows_after_header,
+            comment_char,
+            quote_char,
+            eol_char,
+            null_values.as_ref(),
+            parse_dates,
+        )?;
+
+        let schema = schema.unwrap_or_else(|| Arc::new(inferred_schema));
+        let n_bytes = reader_bytes.deref().len();
+        let estimated_n_rows = (rows_read as f64 / bytes_read as f64 * n_bytes as f64) as usize;
+
         skip_rows += skip_rows_after_header;
+        let file_info = FileInfo {
+            schema,
+            row_estimation: (None, estimated_n_rows),
+        };
         Ok(LogicalPlan::CsvScan {
             path,
-            schema,
+            file_info,
             options: CsvParserOptions {
                 has_header,
                 delimiter,
@@ -365,7 +390,7 @@ impl LogicalPlanBuilder {
 
     pub fn groupby<E: AsRef<[Expr]>>(
         self,
-        keys: Arc<Vec<Expr>>,
+        keys: Vec<Expr>,
         aggs: E,
         apply: Option<Arc<dyn DataFrameUdf>>,
         maintain_order: bool,
@@ -374,6 +399,7 @@ impl LogicalPlanBuilder {
     ) -> Self {
         let current_schema = try_delayed!(self.0.schema(), &self.0, into);
         let current_schema = current_schema.as_ref();
+        let keys = rewrite_projections(keys, current_schema, &[]);
         let aggs = rewrite_projections(aggs.as_ref().to_vec(), current_schema, keys.as_ref());
 
         let mut schema = try_delayed!(
@@ -422,7 +448,7 @@ impl LogicalPlanBuilder {
 
         LogicalPlan::Aggregate {
             input: Box::new(self.0),
-            keys,
+            keys: Arc::new(keys),
             aggs,
             schema: Arc::new(schema),
             apply,
