@@ -602,6 +602,31 @@ fn test_automatic_datetime_parsing() -> PolarsResult<()> {
     Ok(())
 }
 
+#[test]
+#[cfg(feature = "temporal")]
+fn test_automatic_datetime_parsing_default_formats() -> PolarsResult<()> {
+    let csv = r"ts_dmy,ts_dmy_f,ts_dmy_p
+01/01/21 00:00:00,31-01-2021T00:00:00.123,31-01-2021 11:00 AM
+01/01/21 00:15:00,31-01-2021T00:15:00.123,31-01-2021 01:00 PM
+01/01/21 00:30:00,31-01-2021T00:30:00.123,31-01-2021 01:15 PM
+01/01/21 00:45:00,31-01-2021T00:45:00.123,31-01-2021 01:30 PM
+";
+
+    let file = Cursor::new(csv);
+    let df = CsvReader::new(file).with_parse_dates(true).finish()?;
+
+    for col in df.get_column_names() {
+        let ts = df.column(col)?;
+        assert_eq!(
+            ts.dtype(),
+            &DataType::Datetime(TimeUnit::Microseconds, None)
+        );
+        assert_eq!(ts.null_count(), 0);
+    }
+
+    Ok(())
+}
+
 #[test]
 fn test_no_quotes() -> PolarsResult<()> {
     let rolling_stones = r#"linenum,last_name,first_name
