@@ -25,23 +25,9 @@ class ExprDateTimeNameSpace:
         offset: str | timedelta | None = None,
     ) -> pli.Expr:
         """
-        Divide the date/ datetime range into buckets.
+        Divide the date/datetime range into buckets.
 
-        The `every` and `offset` arguments are created with
-        the following string language:
-
-        1ns # 1 nanosecond
-        1us # 1 microsecond
-        1ms # 1 millisecond
-        1s  # 1 second
-        1m  # 1 minute
-        1h  # 1 hour
-        1d  # 1 day
-        1w  # 1 week
-        1mo # 1 calendar month
-        1y  # 1 calendar year
-
-        3d12h4m25s # 3 days, 12 hours, 4 minutes, and 25 seconds
+        Each date/datetime is mapped to the start of its bucket.
 
         Parameters
         ----------
@@ -50,6 +36,24 @@ class ExprDateTimeNameSpace:
         offset
             Offset the window
 
+        Notes
+        -----
+        The `every` and `offset` argument are created with the
+        the following small string formatting language:
+
+        1ns  # 1 nanosecond
+        1us  # 1 microsecond
+        1ms  # 1 millisecond
+        1s   # 1 second
+        1m   # 1 minute
+        1h   # 1 hour
+        1d   # 1 day
+        1w   # 1 week
+        1mo  # 1 calendar month
+        1y   # 1 calendar year
+
+        eg: 3d12h4m25s  # 3 days, 12 hours, 4 minutes, and 25 seconds
+
         Returns
         -------
         Date/Datetime series
@@ -59,70 +63,81 @@ class ExprDateTimeNameSpace:
         >>> from datetime import timedelta, datetime
         >>> start = datetime(2001, 1, 1)
         >>> stop = datetime(2001, 1, 2)
-        >>> s = pl.date_range(start, stop, timedelta(minutes=30), name="dates")
-        >>> s
-        shape: (49,)
-        Series: 'dates' [datetime[μs]]
-        [
-            2001-01-01 00:00:00
-            2001-01-01 00:30:00
-            2001-01-01 01:00:00
-            2001-01-01 01:30:00
-            2001-01-01 02:00:00
-            2001-01-01 02:30:00
-            2001-01-01 03:00:00
-            2001-01-01 03:30:00
-            2001-01-01 04:00:00
-            2001-01-01 04:30:00
-            2001-01-01 05:00:00
-            2001-01-01 05:30:00
-            ...
-            2001-01-01 18:30:00
-            2001-01-01 19:00:00
-            2001-01-01 19:30:00
-            2001-01-01 20:00:00
-            2001-01-01 20:30:00
-            2001-01-01 21:00:00
-            2001-01-01 21:30:00
-            2001-01-01 22:00:00
-            2001-01-01 22:30:00
-            2001-01-01 23:00:00
-            2001-01-01 23:30:00
-            2001-01-02 00:00:00
-        ]
-        >>> s.dt.truncate("1h")
-        shape: (49,)
-        Series: 'dates' [datetime[μs]]
-        [
-            2001-01-01 00:00:00
-            2001-01-01 00:00:00
-            2001-01-01 01:00:00
-            2001-01-01 01:00:00
-            2001-01-01 02:00:00
-            2001-01-01 02:00:00
-            2001-01-01 03:00:00
-            2001-01-01 03:00:00
-            2001-01-01 04:00:00
-            2001-01-01 04:00:00
-            2001-01-01 05:00:00
-            2001-01-01 05:00:00
-            ...
-            2001-01-01 18:00:00
-            2001-01-01 19:00:00
-            2001-01-01 19:00:00
-            2001-01-01 20:00:00
-            2001-01-01 20:00:00
-            2001-01-01 21:00:00
-            2001-01-01 21:00:00
-            2001-01-01 22:00:00
-            2001-01-01 22:00:00
-            2001-01-01 23:00:00
-            2001-01-01 23:00:00
-            2001-01-02 00:00:00
-        ]
-        >>> s.dt.truncate("1h").series_equal(s.dt.truncate(timedelta(hours=1)))
+        >>> df = pl.date_range(
+        ...     start, stop, timedelta(minutes=225), name="dates"
+        ... ).to_frame()
+        >>> df
+        shape: (7, 1)
+        ┌─────────────────────┐
+        │ dates               │
+        │ ---                 │
+        │ datetime[μs]        │
+        ╞═════════════════════╡
+        │ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 03:45:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 07:30:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 11:15:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 15:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 18:45:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 22:30:00 │
+        └─────────────────────┘
+        >>> df.select(pl.col("dates").dt.truncate("1h"))
+        shape: (7, 1)
+        ┌─────────────────────┐
+        │ dates               │
+        │ ---                 │
+        │ datetime[μs]        │
+        ╞═════════════════════╡
+        │ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 03:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 07:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 11:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 15:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 18:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 22:00:00 │
+        └─────────────────────┘
+        >>> df.select(pl.col("dates").dt.truncate("1h")).frame_equal(
+        ...     df.select(pl.col("dates").dt.truncate(timedelta(hours=1)))
+        ... )
         True
 
+        >>> start = datetime(2001, 1, 1)
+        >>> stop = datetime(2001, 1, 1, 1)
+        >>> df = pl.date_range(start, stop, "10m", name="dates").to_frame()
+        >>> df.select(["dates", pl.col("dates").dt.truncate("30m").alias("truncate")])
+        shape: (7, 2)
+        ┌─────────────────────┬─────────────────────┐
+        │ dates               ┆ truncate            │
+        │ ---                 ┆ ---                 │
+        │ datetime[μs]        ┆ datetime[μs]        │
+        ╞═════════════════════╪═════════════════════╡
+        │ 2001-01-01 00:00:00 ┆ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:10:00 ┆ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:20:00 ┆ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:30:00 ┆ 2001-01-01 00:30:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:40:00 ┆ 2001-01-01 00:30:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:50:00 ┆ 2001-01-01 00:30:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 01:00:00 ┆ 2001-01-01 01:00:00 │
+        └─────────────────────┴─────────────────────┘
+
         """
         if offset is None:
             offset = "0ns"
@@ -130,7 +145,143 @@ class ExprDateTimeNameSpace:
             every = _timedelta_to_pl_duration(every)
         if isinstance(offset, timedelta):
             offset = _timedelta_to_pl_duration(offset)
-        return pli.wrap_expr(self._pyexpr.date_truncate(every, offset))
+        return pli.wrap_expr(self._pyexpr.dt_truncate(every, offset))
+
+    def round(
+        self,
+        every: str | timedelta,
+        offset: str | timedelta | None = None,
+    ) -> pli.Expr:
+        """
+        Divide the date/datetime range into buckets.
+
+        Each date/datetime in the first half of the interval
+        is mapped to the start of its bucket.
+        Each date/datetime in the seconod half of the interval
+        is mapped to the end of its bucket.
+
+        Parameters
+        ----------
+        every
+            Every interval start and period length
+        offset
+            Offset the window
+
+        Notes
+        -----
+        The `every` and `offset` argument are created with the
+        the following small string formatting language:
+
+        1ns  # 1 nanosecond
+        1us  # 1 microsecond
+        1ms  # 1 millisecond
+        1s   # 1 second
+        1m   # 1 minute
+        1h   # 1 hour
+        1d   # 1 day
+        1w   # 1 week
+        1mo  # 1 calendar month
+        1y   # 1 calendar year
+
+        eg: 3d12h4m25s  # 3 days, 12 hours, 4 minutes, and 25 seconds
+
+        Returns
+        -------
+        Date/Datetime series
+
+        Warnings
+        --------
+        This functionality is currently experimental and may
+        change without it being considered a breaking change.
+
+        Examples
+        --------
+        >>> from datetime import timedelta, datetime
+        >>> start = datetime(2001, 1, 1)
+        >>> stop = datetime(2001, 1, 2)
+        >>> df = pl.date_range(
+        ...     start, stop, timedelta(minutes=225), name="dates"
+        ... ).to_frame()
+        >>> df
+        shape: (7, 1)
+        ┌─────────────────────┐
+        │ dates               │
+        │ ---                 │
+        │ datetime[μs]        │
+        ╞═════════════════════╡
+        │ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 03:45:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 07:30:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 11:15:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 15:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 18:45:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 22:30:00 │
+        └─────────────────────┘
+        >>> df.select(pl.col("dates").dt.round("1h"))
+        shape: (7, 1)
+        ┌─────────────────────┐
+        │ dates               │
+        │ ---                 │
+        │ datetime[μs]        │
+        ╞═════════════════════╡
+        │ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 04:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 08:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 11:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 15:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 19:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 23:00:00 │
+        └─────────────────────┘
+        >>> df.select(pl.col("dates").dt.round("1h")).frame_equal(
+        ...     df.select(pl.col("dates").dt.round(timedelta(hours=1)))
+        ... )
+        True
+
+        >>> start = datetime(2001, 1, 1)
+        >>> stop = datetime(2001, 1, 1, 1)
+        >>> df = pl.date_range(start, stop, "10m", name="dates").to_frame()
+        >>> df.select(["dates", pl.col("dates").dt.round("30m").alias("round")])
+        shape: (7, 2)
+        ┌─────────────────────┬─────────────────────┐
+        │ dates               ┆ round               │
+        │ ---                 ┆ ---                 │
+        │ datetime[μs]        ┆ datetime[μs]        │
+        ╞═════════════════════╪═════════════════════╡
+        │ 2001-01-01 00:00:00 ┆ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:10:00 ┆ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:20:00 ┆ 2001-01-01 00:30:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:30:00 ┆ 2001-01-01 00:30:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:40:00 ┆ 2001-01-01 00:30:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:50:00 ┆ 2001-01-01 01:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 01:00:00 ┆ 2001-01-01 01:00:00 │
+        └─────────────────────┴─────────────────────┘
+
+        """
+        if offset is None:
+            offset = "0ns"
+        if isinstance(every, timedelta):
+            every = _timedelta_to_pl_duration(every)
+        if isinstance(offset, timedelta):
+            offset = _timedelta_to_pl_duration(offset)
+        return pli.wrap_expr(self._pyexpr.dt_round(every, offset))
 
     def strftime(self, fmt: str) -> pli.Expr:
         """
@@ -994,6 +1145,21 @@ class ExprDateTimeNameSpace:
         """
         return pli.wrap_expr(self._pyexpr.dt_cast_time_zone(tz))
 
+    def tz_localize(self, tz: str) -> pli.Expr:
+        """
+        Localize tz-naive Datetime Series to tz-aware Datetime Series.
+
+        This method takes a naive Datetime Series and makes this time zone aware.
+        It does not move the time to another time zone.
+
+        Parameters
+        ----------
+        tz
+            Time zone for the `Datetime` Series.
+
+        """
+        return pli.wrap_expr(self._pyexpr.dt_tz_localize(tz))
+
     def days(self) -> pli.Expr:
         """
         Extract the days from a Duration type.
